@@ -189,7 +189,7 @@ class OasisAuthServices(ViewSet):
                         cache.set(cache_key, data_cache, self.__cache_timeout_seconds)
                         status_return = status.HTTP_200_OK
                     else:
-                        raise AuthenticationFailed(_("The email/password is incorrect."))
+                        raise AuthenticationFailed(_("Email or Password incorrect."))
                 else:
                     raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
             else:
@@ -197,6 +197,6 @@ class OasisAuthServices(ViewSet):
         except ValidationError as exc:
             raise APIException(msg=exc.detail[0], error="login", http_status=exc.status_code) from exc
         except self.__user.DoesNotExist as exc:
-            raise APIException(msg=_("The email/password is incorrect."), error="login") from exc
+            raise APIException(msg=_("Email or Password incorrect."), error="login") from exc
         else:
             return Response(status=status_return, data=data_return)
